==> v8.3.zip: ru_twords_ru_tw/bible/other/crown.md <==
# венец, корона, венчать, короновать

## Определение:

Венец — это круглый головной убор, который носили правители, короли/цари и королевы/царицы. Слово “венчать” означает “возлагать корону” на голову правителя. В переносном  смысле это слово означает “воздавать честь”.

* Венцы изготавливались из золота или серебра и украшались драгоценными камнями: изумрудами, рубинами и др.
* Во все времена корона являлась символом царской власти и богатства.
* Однако терновый венец, возложенный на голову Иисуса римскими солдатами вместо короны, предназначался для того, чтобы унизить Христа и усугубить Его страдания.
* В древние времена победителей атлетических состязаний награждали венцами, сплетёнными из лавровых ветвей. Апостол Павел говорит о подобном венце во втором послании к Тимофею.
* Словосочетание “венчать славой” означает “воздавать честь”. Мы воздаём Богу честь, когда прославляем Его и исполняем то, что Он велит. Наше прославление подобно возложению венца на Его голову.
* Павел называет верующих своей “радостью и венцом” (Филиппийцам 4:1). Слово “венец” в этом случае используется как символ огромного благословения, которое Павел получил благодаря тому, что его духовные дети сохранили верность Богу.
* Если слово “венец” используется в переносном значении, его можно заменить словами “награда”, “честь”.
* Слово “венчать” можно перевести как “чтить”, “оказывать почтение”.
* Короновать правителя — значит возложить корону на его голову.
* Выражение “увенчать славой и честью” можно перевести как “воздать славу и честь”, “прославить и почтить”.

(См. также: [слава](../kt/glory.md), [царь](../other/king.md), [маслина](../other/olive.md))

## Ссылка на библейский текст:

* [Ин. 19:1-3](rc://*/tn/help/jhn/19/01)
* [Плач 5:15-16](rc://*/tn/help/lam/05/15)
* [Мф. 27:27-29](rc://*/tn/help/mat/27/27)
* [Флп. 4:1-3](rc://*/tn/help/php/04/01)
* [Пс. 21:3-4](rc://*/tn/help/psa/021/003)
* [Откр. 3:9-11](rc://*/tn/help/rev/03/09)

## Данные о слове:

* Номера Стронга: H2213, H3803, H3804, H4502, H5145, H5849, H5850, H6936, G1238, G4735, G4737

==> v9.2.zip: ru_twords_ru_tw/bible/other/crown.md <==
# венец, корона, венчать, короновать
## Определение:

Венец — это круглый головной убор, который носили правители, короли/цари и королевы/царицы. Слово “венчать” означает “возлагать корону” на голову правителя. В переносном  смысле это слово означает “воздавать честь”.

* Венцы изготавливались из золота или серебра и украшались драгоценными камнями: изумрудами, рубинами и др.
* Во все времена корона являлась символом царской власти и богатства.
* Однако терновый венец, возложенный на голову Иисуса римскими солдатами вместо короны, предназначался для того, чтобы унизить Христа и усугубить Его страдания. 
* В древние времена победителей атлетических состязаний награждали венцами, сплетёнными из лавровых ветвей. Апостол Павел говорит о подобном венце во втором послании к Тимофею.
* Словосочетание “венчать славой” означает “воздавать честь”. Мы воздаём Богу честь, когда прославляем Его и исполняем то, что Он велит. Наше прославление подобно возложению венца на Его голову. 
* Павел называет верующих своей “радостью и венцом” (Филиппийцам 4:1). Слово “венец” в этом случае используется как символ огромного благословения, которое Павел получил благодаря тому, что его духовные дети сохранили верность Богу.
*  Если слово “венец” используется в переносном значении, его можно заменить словами “награда”, “честь”. 
*  Слово “венчать” можно перевести как “чтить”, “оказывать почтение”. 
*  Короновать правителя — значит возложить корону на его голову.
*  Выражение “увенчать славой и честью” можно перевести как “воздать славу и честь”, “прославить и почтить”.

(См. также: [слава](../kt/glory.md), [царь](../other/king.md), [маслина](../other/olive.md))

## Ссылка на библейский текст:

* [Ин. 19:1-3](rc://ru/tn/help/jhn/19/01)
* [Плач 5:15-16](rc://ru/tn/help/lam/05/15)
* [Мф. 27:27-29](rc://ru/tn/help/mat/27/27)
* [Флп. 4:1-3](rc://ru/tn/help/php/04/01)
* [Пс. 21:3-4](rc://ru/tn/help/psa/021/003)
* [Откр. 3:9-11](rc://ru/tn/help/rev/03/09)

## Данные о слове:

* Номера Стронга: H2213, H3803, H3804, H4502, H5145, H5849, H5850, H6936, G1238, G4735, G4737
